def pubchem_search(formula):
    from ase.data.pubchem import pubchem_atoms_search
    from ase.io import write
    atoms = pubchem_atoms_search(formula)
    return atoms


def energy(atoms, calculator):
    from gpaw import GPAW

    calc = GPAW(**calculator)
    atoms.center(vacuum=3.0)
    atoms.calc = calc
    return atoms.get_potential_energy()


class RIx:
    _format: str = '7.3f'
    def __init__(self, eA, eB) -> None:
        self.energies_A = energies_A
        self.eB = eB

    @property
    def I_A(self):
        atoms_plus = self.A[1]
        atoms_zero = self.A[0]
        e_plus = atoms_plus.get_potential_energy()
        e_zero = atoms_zero.get_potential_energy()
        I = e_plus - e_zero
        return I

    @property
    def I_B(self):
        atoms_plus = self.B[1]
        atoms_zero = self.B[0]
        e_plus = atoms_plus.get_potential_energy()
        e_zero = atoms_zero.get_potential_energy()
        I = e_plus - e_zero
        return I

    @property
    def A_A(self):
        atoms_minus = self.A[-1]
        atoms_zero = self.A[0]
        e_minus = atoms_minus.get_potential_energy()
        e_zero = atoms_zero.get_potential_energy()
        A = e_zero - e_minus
        return A

    @property
    def A_B(self):
        atoms_minus = self.B[-1]
        atoms_zero = self.B[0]
        e_minus = atoms_minus.get_potential_energy()
        e_zero = atoms_zero.get_potential_energy()
        A = e_zero - e_minus
        return A

    @property
    def nu_A(self):
        return self.I_A - self.A_A

    @property
    def nu_B(self):
        return self.I_B - self.A_B

    @property
    def mu_A(self):
        return -(self.I_A + self.A_A) / 2

    @property
    def mu_B(self):
        return -(self.I_B + self.A_B) / 2

    @property
    def dNA_ele(self):
        return -(self.A_B - self.I_A) / (2*(self.nu_B + self.nu_A))

    @property
    def dNB_ele(self):
        return -self.dNA_nuc

    @property
    def dNA_nuc(self):
        return (self.A_A - self.I_B) / (2*(self.nu_B + self.nu_A))

    @property
    def dNB_nuc(self):
        return -self.dNA_ele

    @property
    def dNA(self):
        return self.dNA_ele + self.dNA_nuc

    @property
    def dNB(self):
        return self.dNB_ele + self.dNB_nuc

    def str_A(self):
        text = f' {self.I_A:{self._format}} | {self.A_A:{self._format}} | '
        text += f'{self.mu_A:{self._format}} | {self.nu_A:{self._format}} | '
        text += f'{self.dNA:{self._format}} | '
        text += f'{self.dNA_ele:{self._format}} | {self.dNA_nuc:{self._format}}'
        return text

    def str_B(self):
        text = f' {self.I_B:{self._format}} | {self.A_B:{self._format}} | '
        text += f'{self.mu_B:{self._format}} | {self.nu_B:{self._format}}'
        return text

    def __str__(self):
        text = '   I_A   |   A_A   |   μ_A   |   η_A   |   ΔNA   | ΔNA_ele | ΔNA_nuc \n'
        text += self.str_A() + '\n'
        text = '   I_B   |   A_B   |   μ_B   |   η_B   |\n'
        text += self.str_B()
        return text
